# pyhepmc

Python bindings for HepMC3.

## Installation

Local installation for testing

    python setup.py build_ext -i

User-wide installation

    python setup.py install --user

System-wide installation

    python setup.py install

## License

pyhepmc is provided under a BSD 3-clause license that can be found in the `LICENSE` file.

The external HepMC3 code included in the repository is not covered by the GPL-v3 license, which can be found in `src/HepMC3/LICENSE`.
